#!/usr/bin/env python
# coding: utf-8

# Copyright (c) Manuel Martins.
# Distributed under the terms of the Modified BSD License.

version_info = (0, 8, 2, 'beta')
__version__ = ".".join(map(str, version_info))
